"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("../../tsr-declarations");
var lib_1 = require("ts-runtime/lib");
var chai_1 = require("chai");
var http_1 = require("http");
var https_1 = require("https");
var noop = require("noop-logger");
var zipkin_1 = require("zipkin");
var zipkin_transport_http_1 = require("zipkin-transport-http");
describe('HttpLogger', function () {
    it('should have correct type', function () {
        var options = {
            endpoint: 'testEndpoint',
            httpInterval: 1000,
            jsonEncoder: zipkin_1.jsonEncoder.JSON_V1,
            timeout: 0,
            maxPayloadSize: 0,
            headers: {},
            agent: new http_1.Agent(),
            log: console
        };
        var httpLogger = lib_1.default.nullable(lib_1.default.ref("HttpLogger.165386231")).assert(new zipkin_transport_http_1.HttpLogger(options));
        chai_1.expect(httpLogger.logSpan).to.be.a('function');
    });
    it('should accept Http(s) Agent or function which returns Agent', function () {
        var agents = [new http_1.Agent(), new https_1.Agent(), function () {
                return new http_1.Agent();
            }, function () {
                return new https_1.Agent();
            },
            function (url) {
                var _urlType = lib_1.default.nullable(lib_1.default.ref("URL.3598831290"));
                lib_1.default.param("url", _urlType).assert(url);
                return new http_1.Agent();
            }, function (url) {
                var _urlType = lib_1.default.nullable(lib_1.default.ref("URL.3598831290"));
                lib_1.default.param("url", _urlType).assert(url);
                return new https_1.Agent();
            }, null, undefined];
        agents.forEach(function (agent) {
            var options = {
                endpoint: 'testEndpoint',
                agent: agent
            };
            var httpLogger = lib_1.default.nullable(lib_1.default.ref("HttpLogger.165386231")).assert(new zipkin_transport_http_1.HttpLogger(options));
            chai_1.expect(httpLogger).to.have.property('agent', agent || null);
        });
    });
    it('should accept loggers containing error function', function () {
        var loggers = [console, noop, undefined];
        loggers.forEach(function (log) {
            var options = {
                endpoint: 'testEndpoint',
                log: log
            };
            var httpLogger = lib_1.default.nullable(lib_1.default.ref("HttpLogger.165386231")).assert(new zipkin_transport_http_1.HttpLogger(options));
            chai_1.expect(httpLogger).to.have.property('log', log || console);
        });
    });
});
